Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
tests\unit\loggers\test_local_logger.py | 70 | 0 | 0 | 100%
tests\unit\loggers\test_tensorboard_logger.py | 104 | 0 | 0 | 100%
tests\unit\test_tm_integration.py | 86 | 0 | 0 | 100%
tests\unit\test_training_interval.py | 152 | 0 | 0 | 100%
tests\unit\test_training_manager.py | 216 | 4 | 0 | 98%
trnbl\__init__.py | 4 | 0 | 0 | 100%
trnbl\loggers\__init__.py | 1 | 0 | 0 | 100%
trnbl\loggers\base.py | 94 | 26 | 0 | 72%
trnbl\loggers\local\__init__.py | 2 | 0 | 0 | 100%
trnbl\loggers\local\build_dist.py | 106 | 106 | 0 | 0%
trnbl\loggers\local\html_frontend.py | 4 | 1 | 0 | 75%
trnbl\loggers\local\locallogger.py | 123 | 9 | 0 | 93%
trnbl\loggers\local\start_server.py | 18 | 13 | 0 | 28%
trnbl\loggers\multi.py | 38 | 38 | 0 | 0%
trnbl\loggers\tensorboard.py | 45 | 1 | 0 | 98%
trnbl\loggers\wandb.py | 46 | 46 | 0 | 0%
trnbl\training_interval.py | 118 | 7 | 0 | 94%
trnbl\training_manager.py | 146 | 11 | 0 | 92%
Total | 1373 | 262 | 0 | 81%

No items found using the specified filter.